@@ -22,7 +22,7 @@ ptxd_make_world_patchin_apply_init()
     if [ -n "${pkg_patch_series}" ]; then
 	# check if specified series file can be found
 	pkg_patch_series="${pkg_patch_dir}/${pkg_patch_series}"
-	if [ \! -e "${pkg_patch_series}" ]; then
+	if [ ! -e "${pkg_patch_series}" ]; then
 	    echo "error: specified series '${pkg_patch_series}' not found"
 	    return 1
 	fi
@@ -62,6 +62,14 @@ ptxd_make_world_patchin_apply_git_init()
     local git_dir
     git_dir="$(git rev-parse --git-dir 2> /dev/null)" || true
 
+    local git_ptx_patches
+    ptxd_in_path PTXDIST_PATH_SCRIPTS git-ptx-patches
+    git_ptx_patches="${ptxd_reply}"
+
+    local git_ptx_refresh_tags_editor
+    ptxd_in_path PTXDIST_PATH_SCRIPTS git-ptx-refresh-tags-editor
+    git_ptx_refresh_tags_editor="${ptxd_reply}"
+
     # is already git repo?
     if [ "${git_dir}" != ".git" ]; then
 	echo "patchin: git: initializing repository"
@@ -70,8 +78,8 @@ ptxd_make_world_patchin_apply_git_init()
 	__git commit -q -m "initial commit" --author="ptxdist-${PTXDIST_VERSION_FULL} <ptxdist@pengutronix.de>" &&
 	__git tag "${pkg_pkg//\~/-}" &&
 	__git tag base &&
-	__git config alias.ptx-patches "!${PTXDIST_TOPDIR}/scripts/git-ptx-patches \"\${@}\"" &&
-	__git config core.editor "${PTXDIST_TOPDIR}/scripts/git-ptx-refresh-tags-editor" &&
+	__git config alias.ptx-patches "!${git_ptx_patches} \"\${@}\"" &&
+	__git config sequence.editor "${git_ptx_refresh_tags_editor}" &&
 	__git config diff.renames false &&
 	__git config core.abbrev 12 &&
 	__git config core.autocrlf false &&
@@ -291,7 +299,7 @@ ptxd_make_world_patchin_apply()
 	popd > /dev/null
 
 	# no patches found
-	if [ \! -s "${tmp_patch_series}" ]; then
+	if [ ! -s "${tmp_patch_series}" ]; then
 	    rm -f "${tmp_patch_series}" &&
 	    unset pkg_patch_series
 	else
@@ -325,7 +333,7 @@ ptxd_make_world_patchin_apply()
 		*) ptxd_bailout "invalid parameter to patch '${patch}' in series file '${pkg_patch_series}'"
 	    esac
 
-	    if [ \! -f "${pkg_patchin_dir}/.ptxdist/patches/${patch}" ]; then
+	    if [ ! -f "${pkg_patchin_dir}/.ptxdist/patches/${patch}" ]; then
 		ptxd_bailout "cannot find patch: '${patch}' specified in series file '${pkg_patch_series}'"
 	    fi
 
@@ -345,7 +353,7 @@ ptxd_make_world_patchin_apply()
     fi &&
 
     # patches
-    if [ \! -e "${pkg_patchin_dir}/patches" ]; then
+    if [ ! -e "${pkg_patchin_dir}/patches" ]; then
 	ln -sf ".ptxdist/patches" "${pkg_patchin_dir}/patches"
     fi || return
 
@@ -385,7 +393,7 @@ ptxd_make_world_patchin_fixup()
 	# - on blackfin they've got symbols with more "_" prefixes than on other platforms
 	# - teach libtool to cope with it
 	#
-	# the second one supresses the adding of "rpath"
+	# the second one suppresses the adding of "rpath"
 	#
 	sed -i \
 	    -e "s=sed -e \"s/\\\\(\.\*\\\\)/\\\\1;/\"=sed -e \"s/\\\\(.*\\\\)/'\"\$ac_symprfx\"'\\\\1;/\"=" \
@@ -459,8 +467,8 @@ ptxd_make_world_patchin_init()
 {
     ptxd_make_world_init || return
 
-    if [ -z "${pkg_url}" -a -z "${pkg_src}" ]; then
-	# no <PKG>_URL and no <PKG>_SOURCE -> assume the package has nothing to patchin.
+    if [ -z "${pkg_url}" -a -z "${pkg_src}" -a "${pkg_parts}" = "${pkg_PKG}" ]; then
+	# no <PKG>_URL, no <PKG>_SOURCE and not other <PKG>_PARTS -> assume the package has nothing to patchin.
 	return
     fi
 
@@ -502,6 +510,34 @@ export -f ptxd_make_world_patchin
 ptxd_make_world_patchin_post() {
     ptxd_make_world_patchin_init || return
 
+    if [ "${pkg_conf_tool}" = "cargo" -o -n "${pkg_cargo_lock}" ]; then
+	{
+	cat << EOF
+[source.ptxdist]
+directory = "${pkg_cargo_home}/source"
+
+[source.crates-io]
+replace-with = "ptxdist"
+local-registry = "/nonexistant"
+
+EOF
+
+    sed -n 's;source = "\(git.*\)#.*;\1;p' "${pkg_dir}/${pkg_cargo_lock}" | sort -u | \
+	sed -n 's;^git+\(.*://[^?]*\)?branch=\(.*\)$;[source."\1"]\ngit = "\1"\nbranch = "\2"\nreplace-with = "ptxdist"\n;p'
+    sed -n 's;source = "\(git.*\)#.*;\1;p' "${pkg_dir}/${pkg_cargo_lock}" | sort -u | \
+	sed -n 's;^git+\(.*://[^?]*\)?rev=\(.*\)$;[source."\1"]\ngit = "\1"\nrev = "\2"\nreplace-with = "ptxdist"\n;p'
+    grep 'source = "git' "${pkg_dir}/${pkg_cargo_lock}" | sort -u | \
+	sed -n 's;^source = "git+\(.*://[^?]*\)#.*";[source."\1"]\ngit = "\1"\nreplace-with = "ptxdist"\n;p'
+    cat << EOF
+
+[build]
+target-dir = "${pkg_build_dir}/target"
+
+[net]
+offline = true
+EOF
+	} > ${pkg_cargo_home}/config.toml
+    fi
     if [ -n "${pkg_patchin_dir}" ]; then (
 	cd "${pkg_conf_dir_abs}" &&
 	if [ -n "${pkg_patch_dir}" ]; then
